==> percona-xtrabackup_8.0.35-30.orig.tar.gz: percona-xtrabackup-8.0.35-30/storage/ndb/src/ndbjtie/jtie/com/mysql/jtie/ArrayWrapper.java <==
/*
 Copyright (c) 2010, 2023, Oracle and/or its affiliates.

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License, version 2.0,
 as published by the Free Software Foundation.

 This program is also distributed with certain software (including
 but not limited to OpenSSL) that is licensed under separate terms,
 as designated in a particular file or component or in included license
 documentation.  The authors of MySQL hereby grant you an additional
 permission to link the program and your derivative works with the
 separately licensed software that they have included with MySQL.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License, version 2.0, for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/
/*
 * ArrayWrapper.java
 */

package com.mysql.jtie;

/**
 * An interface to Java peer classes representing a C/C++ object array type.
 * 
 * Please, note that
 * <ol>
 * <li> no length information is associated with this wrapper class for
 *      arrays and, hence,
 * <li> no bound-checking whatsoever is performed at index access.
 * </ol>
 */
// add warning: access to all memory possible
public interface ArrayWrapper< T > {
    /**
     * Returns the element of this array at a given index.
     * Index may be negative (rendering a true, 1-1 mapping of C/C++ pointers).
     */
    T at(int i);
}

==> percona-xtrabackup_8.4.0-1.orig.tar.gz: percona-xtrabackup-8.4.0-1/storage/ndb/src/ndbjtie/jtie/com/mysql/jtie/ArrayWrapper.java <==
/*
 Copyright (c) 2010, 2024, Oracle and/or its affiliates.

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License, version 2.0,
 as published by the Free Software Foundation.

 This program is designed to work with certain software (including
 but not limited to OpenSSL) that is licensed under separate terms,
 as designated in a particular file or component or in included license
 documentation.  The authors of MySQL hereby grant you an additional
 permission to link the program and your derivative works with the
 separately licensed software that they have either included with
 the program or referenced in the documentation.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License, version 2.0, for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/
/*
 * ArrayWrapper.java
 */

package com.mysql.jtie;

/**
 * An interface to Java peer classes representing a C/C++ object array type.
 * 
 * Please, note that
 * <ol>
 * <li> no length information is associated with this wrapper class for
 *      arrays and, hence,
 * <li> no bound-checking whatsoever is performed at index access.
 * </ol>
 */
// add warning: access to all memory possible
public interface ArrayWrapper< T > {
    /**
     * Returns the element of this array at a given index.
     * Index may be negative (rendering a true, 1-1 mapping of C/C++ pointers).
     */
    T at(int i);
}
